@@ -4,27 +4,17 @@ from typing import List, Mapping, Union
 import torch
 from torch import nn
 
-from .composition import AdapterCompositionBlock, BatchSplit, Fuse, Parallel, Split, Stack, parse_composition
-from .modeling import Adapter, BertFusion
+from .composition import AdapterCompositionBlock, BatchSplit, Fuse, Parallel, Split, Stack
+from .configuration import AdapterConfig
+from .context import AdapterSetup, ForwardContext
+from .modeling import Adapter, BertFusion, ParallelAdapter
 
 
-class AdapterLayerBaseMixin(ABC):
+class AdapterLayerBase(ABC, nn.Module):
     """
-    An abstract base implementation of adapter integration into a Transformer block. In BERT, subclasses of this module
-    are placed in the BertSelfOutput module and in the BertOutput module.
+    Base class for all adaptation methods that require per-layer modules.
     """
 
-    # override this property if layer norm has a different name
-    @property
-    def transformer_layer_norm(self):
-        return self.LayerNorm
-
-    @property
-    @abstractmethod
-    def adapter_config_key(self):
-        """Gets the name of the key by which this adapter location is identified in the adapter configuration."""
-        pass
-
     @property
     def layer_idx(self):
         return getattr(self, "_layer_idx", -1)
@@ -35,14 +25,50 @@ class AdapterLayerBaseMixin(ABC):
         assert idx == layer_idx
         setattr(self, "_layer_idx", idx)
 
+    @abstractmethod
+    def add_adapter(self, adapter_name: str, layer_idx: int):
+        raise NotImplementedError()
+
+    @abstractmethod
+    def delete_adapter(self, adapter_name: str):
+        raise NotImplementedError()
+
+    @abstractmethod
+    def add_fusion_layer(self, adapter_names: Union[List, str]):
+        raise NotImplementedError()
+
+    @abstractmethod
+    def delete_fusion_layer(self, adapter_names: Union[List, str]):
+        raise NotImplementedError()
+
+    @abstractmethod
+    def enable_adapters(self, adapter_setup: AdapterCompositionBlock, unfreeze_adapters: bool, unfreeze_fusion: bool):
+        raise NotImplementedError()
+
+    @abstractmethod
+    def get_adapter(self, adapter_name: str) -> nn.Module:
+        raise NotImplementedError()
+
+
+class AdapterLayer(AdapterLayerBase):
+    def __init__(self, location_key: str, config):
+        super().__init__()
+        self.location_key = location_key
+        self.config = config
+
     def _init_adapter_modules(self):
         self.adapters = nn.ModuleDict(dict())
         self.adapter_fusion_layer = nn.ModuleDict(dict())
 
     def add_adapter(self, adapter_name: str, layer_idx: int):
         self.layer_idx = layer_idx
-        adapter_config = self.config.adapters.get(adapter_name)
-        if adapter_config and adapter_config.get(self.adapter_config_key, None):
+        adapter_config = self.config.adapters.match(
+            adapter_name,
+            config_type=AdapterConfig,
+            layer_idx=self.layer_idx,
+            location_key=self.location_key,
+        )
+        if adapter_config is not None:
             reduction_factor = adapter_config["reduction_factor"]
             if isinstance(reduction_factor, Mapping):
                 if str(self.layer_idx) in reduction_factor:
@@ -56,13 +82,15 @@ class AdapterLayerBaseMixin(ABC):
                         '{"1": 16, "default": 16}'
                     )
 
-            adapter = Adapter(
+            if adapter_config.is_parallel:
+                adapter_class = ParallelAdapter
+            else:
+                adapter_class = Adapter
+            adapter = adapter_class(
+                adapter_name=adapter_name,
                 input_size=self.config.hidden_size,
                 down_sample=self.config.hidden_size // reduction_factor,
-                add_layer_norm_before=adapter_config["ln_before"],
-                add_layer_norm_after=adapter_config["ln_after"],
-                non_linearity=adapter_config["non_linearity"],
-                residual_before_ln=adapter_config["adapter_residual_before_ln"],
+                config=adapter_config,
             )
             adapter.train(self.training)  # make sure training mode is consistent
             self.adapters[adapter_name] = adapter
@@ -74,7 +102,7 @@ class AdapterLayerBaseMixin(ABC):
     def add_fusion_layer(self, adapter_names: Union[List, str]):
         """See BertModel.add_fusion_layer"""
         adapter_names = adapter_names if isinstance(adapter_names, list) else adapter_names.split(",")
-        if self.config.adapters.common_config_value(adapter_names, self.adapter_config_key):
+        if self.config.adapters.common_config_value(adapter_names, self.location_key):
             fusion_config = self.config.adapters.get_fusion(adapter_names)
             fusion = BertFusion(
                 fusion_config,
@@ -95,8 +123,8 @@ class AdapterLayerBaseMixin(ABC):
 
         Args:
             adapter_names: names of adapters to unfreeze (or names of adapters part of the fusion layer to unfreeze)
-            unfreeze_adapters: whether the adapters themselves should be unfreezed
-            unfreeze_fusion: whether the adapter attention layer for the given adapters should be unfreezed
+            unfreeze_adapters: whether the adapter weights should be activated
+            unfreeze_fusion: whether the adapter fusion layer for the given adapters should be activated
         """
         if unfreeze_adapters:
             for adapter_name in adapter_setup.flatten():
@@ -114,47 +142,13 @@ class AdapterLayerBaseMixin(ABC):
                         for param in self.adapter_fusion_layer[sub_setup.name].parameters():
                             param.requires_grad = True
 
-    def get_adapter_preparams(
-        self,
-        adapter_config,
-        hidden_states,
-        input_tensor,
-        fusion_config=None,
-    ):
-        """
-        Retrieves the hidden_states, query (for Fusion), and residual connection according to the set configuratio
+    def get_adapter(self, adapter_name):
+        if adapter_name in self.adapters:
+            return self.adapters[adapter_name]
+        else:
+            return None
 
-        Args:
-            adapter_config: config file according to what the parameters are passed
-            hidden_states: output of previous layer
-            input_tensor: residual connection before FFN
-
-        Returns: hidden_states, query, residual
-
-        """
-        query = None
-
-        if adapter_config["residual_before_ln"]:
-            residual = hidden_states
-
-        if fusion_config is not None and fusion_config["query_before_ln"]:
-            query = hidden_states
-
-        if adapter_config["original_ln_before"]:
-            if self.transformer_layer_norm:
-                hidden_states = self.transformer_layer_norm(hidden_states + input_tensor)
-            else:
-                hidden_states = hidden_states + input_tensor
-
-        if not adapter_config["residual_before_ln"]:
-            residual = hidden_states
-
-        if fusion_config is not None and not fusion_config["query_before_ln"]:
-            query = hidden_states
-
-        return hidden_states, query, residual
-
-    def adapter_stack(self, adapter_setup: Stack, hidden_states, input_tensor, lvl=0):
+    def adapter_stack(self, adapter_setup: Stack, hidden_states, input_tensor, layer_norm, lvl=0):
         """
         Forwards the given input through the given stack of adapters.
         """
@@ -168,23 +162,28 @@ class AdapterLayerBaseMixin(ABC):
                 )
             # Case 1: We have a nested fusion layer -> call fusion method
             if isinstance(adapter_stack_layer, Fuse):
-                hidden_states = self.adapter_fusion(adapter_stack_layer, hidden_states, input_tensor, lvl=lvl + 1)
+                hidden_states = self.adapter_fusion(
+                    adapter_stack_layer, hidden_states, input_tensor, layer_norm, lvl=lvl + 1
+                )
             # Case 2: We have a nested split layer -> call split method
             elif isinstance(adapter_stack_layer, Split):
-                hidden_states = self.adapter_split(adapter_stack_layer, hidden_states, input_tensor, lvl=lvl + 1)
+                hidden_states = self.adapter_split(
+                    adapter_stack_layer, hidden_states, input_tensor, layer_norm, lvl=lvl + 1
+                )
             # Case 3: We have a nested parallel layer -> call parallel method
             elif isinstance(adapter_stack_layer, Parallel):
                 hidden_states, input_tensor = self.adapter_parallel(
-                    adapter_stack_layer, hidden_states, input_tensor, lvl=lvl + 1
+                    adapter_stack_layer, hidden_states, input_tensor, layer_norm, lvl=lvl + 1
                 )
             # Case 4: We have a nested batch split block -> call batchsplit method
             elif isinstance(adapter_stack_layer, BatchSplit):
-                hidden_states = self.adapter_batchsplit(adapter_stack_layer, hidden_states, input_tensor, lvl=lvl + 1)
+                hidden_states = self.adapter_batchsplit(
+                    adapter_stack_layer, hidden_states, input_tensor, layer_norm, lvl=lvl + 1
+                )
             # Case 5: We have a single adapter which is part of this module -> forward pass
             elif adapter_stack_layer in self.adapters:
                 adapter_layer = self.adapters[adapter_stack_layer]
-                adapter_config = self.config.adapters.get(adapter_stack_layer)
-                hidden_states, _, residual = self.get_adapter_preparams(adapter_config, hidden_states, input_tensor)
+                hidden_states, _, residual = adapter_layer.pre_forward(hidden_states, input_tensor, layer_norm)
                 hidden_states, _, up = adapter_layer(hidden_states, residual_input=residual)
                 # as this stack might be part of a fusion block, return the adapter up-projection output here
                 # together with the final output (with potential residuals & norms) if we reached the last block of the stack
@@ -196,15 +195,15 @@ class AdapterLayerBaseMixin(ABC):
         # or no adapter was found. In both cases, we don't need to set the second return value for fusion
         return hidden_states, None, input_tensor
 
-    def adapter_fusion(self, adapter_setup: Fuse, hidden_states, input_tensor, lvl=0):
+    def adapter_fusion(self, adapter_setup: Fuse, hidden_states, input_tensor, layer_norm, lvl=0):
         """
         Performs adapter fusion with the given adapters for the given input.
         """
         # config of _last_ fused adapter is significant
-        adapter_config = self.config.adapters.get(adapter_setup.last())
         fusion_config = self.config.adapters.get_fusion(adapter_setup.name)
-        hidden_states, query, residual = self.get_adapter_preparams(
-            adapter_config, hidden_states, input_tensor, fusion_config=fusion_config
+        last_adapter = self.adapters[adapter_setup.last()]
+        hidden_states, query, residual = last_adapter.pre_forward(
+            hidden_states, input_tensor, layer_norm, fusion_config=fusion_config
         )
 
         up_list = []
@@ -212,7 +211,7 @@ class AdapterLayerBaseMixin(ABC):
         for adapter_block in adapter_setup:
             # Case 1: We have a nested stack -> call stack method
             if isinstance(adapter_block, Stack):
-                _, up, _ = self.adapter_stack(adapter_block, hidden_states, input_tensor, lvl=lvl + 1)
+                _, up, _ = self.adapter_stack(adapter_block, hidden_states, input_tensor, layer_norm, lvl=lvl + 1)
                 if up is not None:  # could be none if stack is empty
                     up_list.append(up)
             # Case 2: We have a single adapter which is part of this module -> forward pass
@@ -242,13 +241,13 @@ class AdapterLayerBaseMixin(ABC):
 
         return hidden_states
 
-    def adapter_split(self, adapter_setup: Split, hidden_states, input_tensor, lvl=0):
+    def adapter_split(self, adapter_setup: Split, hidden_states, input_tensor, layer_norm, lvl=0):
         """
         Splits the given input between the given adapters.
         """
         # config of _first_ of splitted adapters is significant
-        adapter_config = self.config.adapters.get(adapter_setup.first())
-        hidden_states, _, residual = self.get_adapter_preparams(adapter_config, hidden_states, input_tensor)
+        first_adapter = self.adapters[adapter_setup.first()]
+        hidden_states, query, residual = first_adapter.pre_forward(hidden_states, input_tensor, layer_norm)
 
         # split hidden representations and residuals at split index
         split_hidden_states = [
@@ -268,17 +267,17 @@ class AdapterLayerBaseMixin(ABC):
             # Case 1: We have a nested stack -> call stack method
             if isinstance(adapter_block, Stack):
                 split_hidden_states[i], _, _ = self.adapter_stack(
-                    adapter_block, split_hidden_states[i], split_input_tensor[i], lvl=lvl + 1
+                    adapter_block, split_hidden_states[i], split_input_tensor[i], layer_norm, lvl=lvl + 1
                 )
             # Case 2: We have a nested split -> recursively call split
             elif isinstance(adapter_block, Split):
                 split_hidden_states[i] = self.adapter_split(
-                    adapter_block, split_hidden_states[i], split_input_tensor[i], lvl=lvl + 1
+                    adapter_block, split_hidden_states[i], split_input_tensor[i], layer_norm, lvl=lvl + 1
                 )
             # Case 3: We have a nested batch split -> call batch split method
             elif isinstance(adapter_block, BatchSplit):
                 split_hidden_states[i] = self.adapter_batchsplit(
-                    adapter_block, split_hidden_states[i], split_input_tensor[i], lvl=lvl + 1
+                    adapter_block, split_hidden_states[i], split_input_tensor[i], layer_norm, lvl=lvl + 1
                 )
             # Case 4: We have a single adapter which is part of this module -> forward pass
             elif adapter_block in self.adapters:
@@ -296,19 +295,18 @@ class AdapterLayerBaseMixin(ABC):
         hidden_states = torch.cat(split_hidden_states, dim=1)
         return hidden_states
 
-    def adapter_parallel(self, adapter_setup: Parallel, hidden_states, input_tensor, lvl=0):
+    def adapter_parallel(self, adapter_setup: Parallel, hidden_states, input_tensor, layer_norm, lvl=0):
         """
         For parallel execution of the adapters on the same input. This means that the input is repeated N times before
         feeding it to the adapters (where N is the number of adapters).
         """
-        # We assume that all adapters have the same config
-        adapter_config = self.config.adapters.get(adapter_setup.first())
 
-        if not self.config.adapters.is_parallelized:
+        context = ForwardContext.get_context()
+        if not context.adapters_parallelized:
             orig_batch_size = input_tensor.shape[0]
             input_tensor = input_tensor.repeat(self.config.adapters.active_setup.parallel_channels, 1, 1)
             hidden_states = hidden_states.repeat(self.config.adapters.active_setup.parallel_channels, 1, 1)
-            self.config.adapters.is_parallelized = True
+            context.adapters_parallelized = True
         else:
             # The base model should handle replication of input.
             # Therefore, we assume the (replicated) input batch to be divisible by the number of parallel channels.
@@ -318,7 +316,9 @@ class AdapterLayerBaseMixin(ABC):
                 )
             orig_batch_size = hidden_states.shape[0] // adapter_setup.parallel_channels
 
-        hidden_states, _, residual = self.get_adapter_preparams(adapter_config, hidden_states, input_tensor)
+        # We assume all adapters have the same config
+        first_adapter = self.adapters[adapter_setup.first()]
+        hidden_states, _, residual = first_adapter.pre_forward(hidden_states, input_tensor, layer_norm)
 
         # sequentially feed different parts of the blown-up batch into different adapters
         children_hidden = []
@@ -329,6 +329,7 @@ class AdapterLayerBaseMixin(ABC):
                     child,
                     hidden_states[i * orig_batch_size : (i + 1) * orig_batch_size],
                     input_tensor[i * orig_batch_size : (i + 1) * orig_batch_size],
+                    layer_norm,
                     lvl=lvl + 1,
                 )
                 children_hidden.append(child_hidden_states)
@@ -338,6 +339,7 @@ class AdapterLayerBaseMixin(ABC):
                     child,
                     hidden_states[i * orig_batch_size : (i + 1) * orig_batch_size],
                     input_tensor[i * orig_batch_size : (i + 1) * orig_batch_size],
+                    layer_norm,
                     lvl=lvl + 1,
                 )
                 children_hidden.append(child_hidden_states)
@@ -364,7 +366,7 @@ class AdapterLayerBaseMixin(ABC):
         hidden_states = torch.cat(children_hidden, 0)
         return hidden_states, input_tensor
 
-    def adapter_batchsplit(self, adapter_setup: BatchSplit, hidden_states, input_tensor, lvl=0):
+    def adapter_batchsplit(self, adapter_setup: BatchSplit, hidden_states, input_tensor, layer_norm, lvl=0):
         if not sum(adapter_setup.batch_sizes) == hidden_states.shape[0]:
             raise IndexError(
                 "The given batch has a size of {} which is not compatible with batch_sizes {}".format(
@@ -372,8 +374,8 @@ class AdapterLayerBaseMixin(ABC):
                 )
             )
 
-        adapter_config = self.config.adapters.get(adapter_setup.first())
-        hidden_states, _, residual = self.get_adapter_preparams(adapter_config, hidden_states, input_tensor)
+        first_adapter = self.adapters[adapter_setup.first()]
+        hidden_states, _, residual = first_adapter.pre_forward(hidden_states, input_tensor, layer_norm)
         children_hidden = []
         for i, adapter_block in enumerate(adapter_setup):
             # compute ids of sequences thet should be passed to the ith adapter
@@ -387,6 +389,7 @@ class AdapterLayerBaseMixin(ABC):
                     adapter_block,
                     hidden_states[batch_idx[0] : batch_idx[1]],
                     input_tensor[batch_idx[0] : batch_idx[1]],
+                    layer_norm,
                     lvl=lvl + 1,
                 )
                 children_hidden.append(child)
@@ -396,6 +399,7 @@ class AdapterLayerBaseMixin(ABC):
                     adapter_block,
                     hidden_states[batch_idx[0] : batch_idx[1]],
                     input_tensor[batch_idx[0] : batch_idx[1]],
+                    layer_norm,
                     lvl=lvl + 1,
                 )
                 children_hidden.append(child)
@@ -405,6 +409,7 @@ class AdapterLayerBaseMixin(ABC):
                     adapter_block,
                     hidden_states[batch_idx[0] : batch_idx[1]],
                     input_tensor[batch_idx[0] : batch_idx[1]],
+                    layer_norm,
                     lvl=lvl + 1,
                 )
                 children_hidden.append(child)
@@ -430,15 +435,15 @@ class AdapterLayerBaseMixin(ABC):
         hidden_states = torch.cat(children_hidden, 0)
         return hidden_states
 
-    def adapters_forward(self, hidden_states, input_tensor, **kwargs):
+    def adapter_layer_forward(self, hidden_states, input_tensor, layer_norm):
         """
         Called for each forward pass through adapters.
         """
-        if hasattr(self.config, "adapters"):
-            # First check for given arguments before falling back to defined setup
-            adapter_setup = kwargs.pop("adapter_names", None)
-            if adapter_setup is not None:
-                adapter_setup = parse_composition(adapter_setup)
+        if getattr(self.config, "is_adaptable", False):
+            # First check current context before falling back to defined setup
+            context = AdapterSetup.get_context()
+            if context is not None:
+                adapter_setup = context.adapter_setup
             else:
                 adapter_setup = self.config.adapters.active_setup
         else:
@@ -447,31 +452,36 @@ class AdapterLayerBaseMixin(ABC):
             self.config.adapters.skip_layers is not None and self.layer_idx in self.config.adapters.skip_layers
         )
         if not skip_adapters and (len(set(self.adapters.keys()) & adapter_setup.flatten()) > 0):
+            input_hidden_states = hidden_states
+
             if isinstance(adapter_setup, Stack):
-                hidden_states, _, input_tensor = self.adapter_stack(adapter_setup, hidden_states, input_tensor)
+                hidden_states, _, input_tensor = self.adapter_stack(
+                    adapter_setup, hidden_states, input_tensor, layer_norm
+                )
             elif isinstance(adapter_setup, Fuse):
-                hidden_states = self.adapter_fusion(adapter_setup, hidden_states, input_tensor)
+                hidden_states = self.adapter_fusion(adapter_setup, hidden_states, input_tensor, layer_norm)
             elif isinstance(adapter_setup, Split):
-                hidden_states = self.adapter_split(adapter_setup, hidden_states, input_tensor)
+                hidden_states = self.adapter_split(adapter_setup, hidden_states, input_tensor, layer_norm)
             elif isinstance(adapter_setup, Parallel):
                 # notice that we are overriding input tensor here to keep the same dim as hidden_states for the residual
                 # in case we were blowing up the batch for parallel processing of multiple adapters for the same input
-                hidden_states, input_tensor = self.adapter_parallel(adapter_setup, hidden_states, input_tensor)
+                hidden_states, input_tensor = self.adapter_parallel(
+                    adapter_setup, hidden_states, input_tensor, layer_norm
+                )
             elif isinstance(adapter_setup, BatchSplit):
-                hidden_states = self.adapter_batchsplit(adapter_setup, hidden_states, input_tensor)
+                hidden_states = self.adapter_batchsplit(adapter_setup, hidden_states, input_tensor, layer_norm)
             else:
                 raise ValueError(f"Invalid adapter setup {adapter_setup}")
 
-            last_config = self.config.adapters.get(adapter_setup.last())
-            if last_config["original_ln_after"]:
-                if self.transformer_layer_norm:
-                    hidden_states = self.transformer_layer_norm(hidden_states + input_tensor)
-                else:
-                    hidden_states = hidden_states + input_tensor
+            last_adapter = self.adapters[adapter_setup.last()]
+            hidden_states = last_adapter.post_forward(hidden_states, input_hidden_states, input_tensor, layer_norm)
 
-        elif self.transformer_layer_norm:
-            hidden_states = self.transformer_layer_norm(hidden_states + input_tensor)
+        elif layer_norm:
+            hidden_states = layer_norm(hidden_states + input_tensor)
         else:
             hidden_states = hidden_states + input_tensor
 
         return hidden_states
+
+    def forward(self, hidden_states, input_tensor, layer_norm):
+        return self.adapter_layer_forward(hidden_states, input_tensor, layer_norm)
